"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
exports.default = format;
/**
 * Get formatted commit message
 * @param input object containing structured results
 * @param debug show debug information in commit message
 * @return formatted debug message
 */
function format(input, debug = false) {
    const results = debug
        ? Object.entries(input).reduce((registry, [name, value]) => {
            registry[name] =
                value === null ? chalk_1.default.grey(`<${name}>`) : chalk_1.default.bold(value);
            return registry;
        }, {})
        : input;
    // Return formatted string
    const { type, scope, subject, body, footer } = results;
    return [
        `${type}${scope ? '(' : ''}${scope}${scope ? ')' : ''}${type || scope ? ':' : ''} ${subject}`,
        body,
        footer,
    ]
        .filter(Boolean)
        .join('\n');
}
//# sourceMappingURL=format.js.map